@@ -1,11 +1,9 @@
-from typing import Optional, Union
-
 from pydantic import BaseModel, ConfigDict, Field
 
 from .callback import Callback
 from .external_documentation import ExternalDocumentation
 from .parameter import Parameter
-from .reference import Reference
+from .reference import ReferenceOr
 from .request_body import RequestBody
 from .responses import Responses
 from .security_requirement import SecurityRequirement
@@ -20,19 +18,19 @@ class Operation(BaseModel):
         - https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.3.md#operationObject
     """
 
-    tags: Optional[list[str]] = None
-    summary: Optional[str] = None
-    description: Optional[str] = None
-    externalDocs: Optional[ExternalDocumentation] = None
-    operationId: Optional[str] = None
-    parameters: Optional[list[Union[Parameter, Reference]]] = None
-    request_body: Optional[Union[RequestBody, Reference]] = Field(None, alias="requestBody")
+    tags: list[str] | None = None
+    summary: str | None = None
+    description: str | None = None
+    externalDocs: ExternalDocumentation | None = None
+    operationId: str | None = None
+    parameters: list[ReferenceOr[Parameter]] | None = None
+    request_body: ReferenceOr[RequestBody] | None = Field(None, alias="requestBody")
     responses: Responses
-    callbacks: Optional[dict[str, Callback]] = None
+    callbacks: dict[str, Callback] | None = None
 
     deprecated: bool = False
-    security: Optional[list[SecurityRequirement]] = None
-    servers: Optional[list[Server]] = None
+    security: list[SecurityRequirement] | None = None
+    servers: list[Server] | None = None
     model_config = ConfigDict(
         # `Callback` contains an unresolvable forward reference, will rebuild in `__init__.py`:
         defer_build=True,
